@@ -4,9 +4,10 @@ General tools useful to create NeXus format files.
 
 __author__ = "Diamond Light Source - Scientific Software"
 __email__ = "scientificsoftware@diamond.ac.uk"
-__version__ = "0.6.8"
+__version__ = "0.6.9"
 __version_tuple__ = tuple(int(x) for x in __version__.split("."))
 
+import logging
 import re
 from datetime import datetime
 from pathlib import Path
@@ -16,6 +17,9 @@ import h5py
 import numpy as np
 import pint
 
+# Logging set up
+logging.getLogger("nexgen").addHandler(logging.NullHandler())
+
 # Initialize registry and a Quantity constructor
 ureg = pint.UnitRegistry()
 Q_ = ureg.Quantity
