@@ -9,13 +9,12 @@ from pathlib import Path
 
 import freephil
 
+from .. import log
 from ..nxs_copy import CopyNexus, CopyTristanNexus
 from . import full_copy_parser, tristan_copy_parser, version_parser
 
 # Define a logger object and a formatter
-logger = logging.getLogger("CopyNeXus")
-logger.setLevel(logging.DEBUG)
-formatter = logging.Formatter("%(levelname)s %(message)s")
+logger = logging.getLogger("nexgen.CopyNeXus")
 
 # Phil scopes
 general_scope = freephil.parse(
@@ -100,6 +99,9 @@ def copy_nexus(args):
         working_phil.show(attributes_level=args.attributes_level)
         sys.exit()
 
+    # Configure logging
+    log.config()
+
     logger.info("Copy metadata from one NeXus file to another.")
 
     # Path to data file and original nexus file
@@ -144,6 +146,9 @@ def copy_tristan_nexus(args):
         working_phil.show(attributes_level=args.attributes_level)
         sys.exit()
 
+    # Configure logging
+    log.config()
+
     logger.info("Copy metadata from Tristan NeXus file.")
 
     # Path to data and original nexus file
@@ -227,13 +232,6 @@ parser_tristan.set_defaults(func=copy_tristan_nexus)
 
 
 def main():
-    # Define a stream handler
-    CH = logging.StreamHandler(sys.stdout)
-    CH.setLevel(logging.DEBUG)
-    CH.setFormatter(formatter)
-    # Add handler to logger
-    logger.addHandler(CH)
-
     args = parser.parse_args()
     args.func(args)
 
