@@ -21,7 +21,7 @@ from .. import (
 )
 from . import calculate_origin, create_attributes, set_dependency
 
-NXclass_logger = logging.getLogger("NeXusGenerator.writer.NXclass")
+NXclass_logger = logging.getLogger("nexgen.NXclass_writers")
 NXclass_logger.setLevel(logging.DEBUG)
 
 
@@ -255,7 +255,10 @@ def write_NXsample(
             # Write {axisname}_increment_set and {axis_name}_end datasets
             if data_type[0] == "images":
                 increment_set = np.repeat(goniometer["increments"][idx], len(osc_range))
-                nxsample_ax.create_dataset(ax + "_increment_set", data=increment_set)
+                nxsample_ax.create_dataset(
+                    ax + "_increment_set",
+                    data=goniometer["increments"][idx],
+                )  # increment_set
                 nxsample_ax.create_dataset(ax + "_end", data=osc_range + increment_set)
         elif ax in scan_axes:
             # For translations
@@ -848,4 +851,4 @@ def write_NXnote(nxsfile: h5py.File, loc: str, info: Dict):
             if type(v) is str:
                 v = np.string_(v)
             nxnote.create_dataset(k, data=v)
-            NXclass_logger.info(f"{k} dataset writte in {loc}.")
+            NXclass_logger.info(f"{k} dataset written in {loc}.")
